# ServiceProtocolConfig

Protocol configuration for an Applicaiton Service. This configuration is dependent on the type of Service and the type of protocol used  (eg. HTTP). 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**http_config** | [**ServiceHttpConfig**](ServiceHttpConfig.md) |  | [optional] 
**expose_config** | [**ServiceExposeConfig**](ServiceExposeConfig.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


